%% Section title: creating variables
% Section titles are helpful for script organizing! When you make any changes within one section it's highlighted!
% Comment - always add comments to your scripts! So you can remember what
% you we doing!
a=[1,2,3,4,5]; % you can put a comment near the line to explain what it's doing
% b=[1,2,3; 4,5,6; 7,8,9;]; % if you put % before the command, this line
% will not be executed. Useful if you want to make things only once, but
% do't want to loose the line. 

a=5; % assign a value to the variable
a = [1,2,3,4,5]; % assign a row of values to the variable (NB! Variable "a" is rewritten!) 
a=[1;2;3;4;5]; % assign a column of values to the variable (NB! Variable "a" is rewritten!) 
b=[1,2,3; 4,5,6; 7,8,9;]; %rows and columns in one variable
%to see the content of variable you can either type it's name in the
%commant window:
b
%or double click on the variable in the workspace.

%To execute the whole script: F5 or in the upper panel Editor -> Run
%To execute the section: click any place in your section (has to be
%highlighted), press Ctrl+Enter
%To execute one line or part of the line: highlight and F9 or mouse right
%click and "evaluate selection"
%% Section 2: deleting variables
clear a %delete variable a
clear a b %delete variables a and b
clear all %delete all variables
clearvars -except a  %delete all variables except for a

%NB if you run all the script, these lines will also execute and your
%variables will be deleted!

%% Saving variables
%sometimes you want to save same (or all) of your workspace for later use
save myWorkSpace %save all the workspace variables to "myWorkSpace.mat"
save myWorkSpace a b  %save variables a and b to the file "myWorkSpace.mat" NB the file will be rewritten!

% to add variable to olready existing .mat file:
new=[1:5]; %create new variable
%Create a MAT-file object connected to the existing MAT-file named myFile.mat. 
%Enable write access to the MAT-file by setting Writable to true.
m=matfile('myWorkSpace.mat','Writable',true); 
m.c=new; %save variable "new" to the .mat file that is connected through "m" and name it "c"

%% Subsetting
b=[1,2,3; 4,5,6; 7,8,9;];
% b(row, column)
c=b(1,2); % element from the 1st row, 2nd column 
% b(:, column) - all rows in this column
% b(row, :) - all columns in this row
column2=b(:,2); %only 2nd column
row2=b(2,:); %only 2nd row
c=b(1:2,:); %only first 2 rows and all columns
c=b(:,1:2); %all rows and only first 2 columns 
c=b(2:end,:); %rows from 2nd till the last one and all columns
c=b(:,2:end); %all rows and columns 2nd till the last one

%% Simple operations
b=[1,2,3; 4,5,6; 7,8,9;]; % just in case you don't have it done already
d=b^2 %matrix way
d=b.^2 % "normal" way NB the . 

b2=[2,2,2;2,2,2;2,2,2];

b*b2 %matrix way
b.*b2% "normal" way 

%% Dates in matlab

%NB! Newer versions of MATLAB have new way of working with the dates!
%Google it if you need, but the "old" should still be possible to use. 

dates=[2017, 5, 4, 19, 51, 20 ]; %datetime as separate numbers in different columns
dates2=datenum(dates); %datetime as one number -  numeric array that represents each point in time as the number of days from January 0, 0000 

dates3 = datestr(dates2); %datetime as string
dates4=datevec(dates2); %datetime as vector (same as we created in the beginning)

%% Time series

%make variable that has timestamp and measurement value
data=[datenum(2017,5,4), 5; datenum(2017,5,5), 7; ...
    datenum(2017,5,6), 8];

%make another variable that has timestamp and measurement value
data2=[datenum(2017,6,4), 45; datenum(2017,6,5), 89; ...
    datenum(2017,6,6), 12];

%merge variables together
DATA=[data;data2];

%make vector of datetime values and add it to the initial variable.
%NB Every time you evaluate this line, new values will be added! 
DATA=[DATA, datevec(DATA(:,1))];

%choose all columns and only those rows that have "5" in the 4th column (only may values)
may=DATA(DATA(:,4)==5, :);

%choose columns from 1 to 5 and only those rows that have "5" in the 4th column (only may values)
may=DATA(DATA(:,4)==5, 1:5)

%choose columns from 1 to 5 and only those rows that have values more than "5" in the 4th column
may=DATA(DATA(:,4)>5, 1:5)

%choose columns from 1 to 5 and only those rows that have "5" in the 4th
%column and "5" in the 5th column (olnly 5th of May data)
may=DATA(DATA(:,4)==5 & DATA(:,5)==5, 1:5)

%save condition as a separate variable
ind=DATA(:,4)==5 & DATA(:,5)==5;  %AND
may=DATA(ind, 1:5)

ind2=DATA(:,4)==5 | DATA(:,4)==6;   %OR
may=DATA(ind2,1:5)